<?php

namespace App\Http\Controllers;

use App\Models\Countries;
use App\Models\EsimPackagesList;
use App\Models\EsimPackagesListCountries;
use App\Models\EsimPackagesListGroups;
use App\Models\EsimPackagesListRoamingEnabled;
use App\Models\MyPackages;
use App\Models\MyPackagesRegionCountries;
use App\Models\Regions;
use App\Models\User;
use App\Models\Setting;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;
use Hash;
use Auth;
use GuzzleHttp\Client;

class PackagesController extends Controller
{

    public function sync_packages()
    {
        $setting = Setting::first();
        $client = new Client();
        $apiKey = $setting->api_key;
        $url = $setting->base_url . "catalogue";

        try {

            $response = $client->request('GET', $url, [
                'headers' => [
                    'X-API-Key' => $apiKey,
                    'Content-Type' => 'application/json',
                ],
                'query' => [
                    'perPage' => 10000,
                ],
            ]);
            $data = json_decode($response->getBody(), true);
            if (!empty($data)) {

                EsimPackagesList::whereNotNull('id')->delete();
                EsimPackagesListCountries::whereNotNull('id')->delete();
                EsimPackagesListRoamingEnabled::whereNotNull('id')->delete();
                EsimPackagesListGroups::whereNotNull('id')->delete();

                foreach ($data['bundles'] as $bundle) {
                    $BundRec = array();
                    $BundRec['name'] = $bundle['name'];
                    $BundRec['description'] = $bundle['description'];
                    $BundRec['dataAmount'] = $bundle['dataAmount'];
                    $BundRec['duration'] = $bundle['duration'];
                    $BundRec['autostart'] = $bundle['autostart'];
                    $BundRec['unlimited'] = $bundle['unlimited'];
                    $BundRec['imageUrl'] = $bundle['imageUrl'];
                    $BundRec['price'] = $bundle['price'];
                    $BundRec['created_by'] = Auth::user()->id;
                    $BundRecData = EsimPackagesList::create($BundRec);
                    if (!empty($bundle['countries'])) {
                        foreach ($bundle['countries'] as $bundRecCount) {
                            $BundRecCountry['esim_packages_list_id'] = $BundRecData->id;
                            $BundRecCountry['name'] = $bundRecCount['name'];
                            $BundRecCountry['region'] = $bundRecCount['region'];
                            $BundRecCountry['iso'] = $bundRecCount['iso'];
                            EsimPackagesListCountries::create($BundRecCountry);
                        }
                    }
                    if (!empty($bundle['roamingEnabled'])) {
                        foreach ($bundle['roamingEnabled'] as $bundroamingEn) {
                            $bundroamingEnabled['esim_packages_list_id'] = $BundRecData->id;
                            $bundroamingEnabled['name'] = $bundroamingEn['name'];
                            $bundroamingEnabled['region'] = $bundroamingEn['region'];
                            $bundroamingEnabled['iso'] = $bundroamingEn['iso'];
                            EsimPackagesListRoamingEnabled::create($bundroamingEnabled);
                        }
                    }
                    if (!empty($bundle['groups'])) {
                        foreach ($bundle['groups'] as $bundgro) {
                            $bundroaminggroup['esim_packages_list_id'] = $BundRecData->id;
                            $bundroaminggroup['name'] = $bundgro;
                            EsimPackagesListGroups::create($bundroaminggroup);
                        }
                    }
                }
                return redirect()->route('admin.manage_esim_packages')->with('success', 'Successfully Updated.');
            } else {
                return back()->with('error', 'No record fetch.');
            }

        } catch (Exception $e) {
            return back()->with('error', 'Something went wrong!');
        }

    }

    public function manage_esim_packages()
    {
        $packages = EsimPackagesList::get();
        $setting = Setting::first();
        return view("admin.manage_esim_packages", compact('packages', 'setting'));
    }

    public function make_mine($id)
    {
        $package = EsimPackagesList::findOrFail(decrypt($id));
        $setting = Setting::first();
        $countries = Countries::all();
        $regions = Regions::all();
        return view("admin.make_mine", compact('package', 'setting', 'countries', 'regions'));
    }

    public function save_mine_packages(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'title' => 'required',
            'price' => 'required',
            'package_id' => 'required',
            'country_region_id' => 'required',
            'type' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }

        $originalPackage = EsimPackagesList::findOrFail($request->package_id);
        $check = MyPackages::where('title', $request->title)->count();
        if ($check > 0) {
            return back()->withInput()->with('error', 'This package is already added.');
            dd("stop");
        }
        $data['original_package_name'] = $originalPackage->name;
        $data['original_package_description'] = $originalPackage->description;
        $data['original_package_dataAmount'] = $originalPackage->dataAmount;
        $data['original_package_duration'] = $originalPackage->duration;
        $data['original_package_autostart'] = $originalPackage->autostart;
        $data['original_package_imageUrl'] = $originalPackage->imageUrl;
        $data['original_package_price'] = $originalPackage->price;
        $data['title'] = $request->title;
        $data['price'] = $request->price;
        $data['type'] = $request->type;
        $data['created_by'] = Auth::user()->id;
        if (isset($request->description) && !empty($request->description)) {
            $data['description'] = $request->description;
        }
        $myRecord = MyPackages::create($data);
        if (isset($request->country_region_id)) {
            foreach ($request->country_region_id as $rec) {
                $data1['my_packages'] = $myRecord->id;
                $data1['country_region_id'] = $rec;
                $data1['type'] = $request->type;
                MyPackagesRegionCountries::create($data1);
            }
        }
        return redirect()->route('admin.manage_esim_packages')->with('success', 'Successfully Added.');
    }

    public function manage_my_packages()
    {
        $packages = MyPackages::all();
        $setting = Setting::first();
        return view("admin.manage_my_packages", compact('packages', 'setting'));
    }

    public function delete_custom_package($id)
    {
        MyPackages::findOrFail(decrypt($id))->delete();
        MyPackagesRegionCountries::where('my_packages', decrypt($id))->delete();
        return redirect()->back()->with('success', 'Successfully Deleted.');
    }

    public function edit_custom_package($id)
    {
        $package = MyPackages::findOrFail(decrypt($id));
        $setting = Setting::first();
        $countries = Countries::all();
        $regions = Regions::all();
        $previous = MyPackagesRegionCountries::where('my_packages', $package->id)->pluck('country_region_id')->toArray();
        return view("admin.edit_custom_package", compact('package', 'setting', 'countries', 'regions', 'previous'));
    }

    public function update_mine_packages(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required',
            'title' => 'required',
            'price' => 'required',
            'country_region_id' => 'required',
            'type' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }

        $originalPackage = MyPackages::findOrFail($request->id);
        $originalPackage->title = $request->title;
        $originalPackage->price = $request->price;
        $originalPackage->type = $request->type;
        $originalPackage->updated_by = Auth::user()->id;
        if (isset($request->description) && !empty($request->description)) {
            $originalPackage->description = $request->description;
        }
        $originalPackage->update();
        if (isset($request->country_region_id)) {
            MyPackagesRegionCountries::where('my_packages', $request->id)->delete();
            foreach ($request->country_region_id as $rec) {
                $data1['my_packages'] = $request->id;
                $data1['country_region_id'] = $rec;
                $data1['type'] = $request->type;
                MyPackagesRegionCountries::create($data1);
            }
        }
        return redirect()->route('admin.manage_my_packages')->with('success', 'Successfully Updated.');
    }

}
