<?php

namespace App\Http\Controllers;

use App\Models\RegionCountries;
use App\Models\Regions;
use Illuminate\Http\Request;
use App\Models\Countries;
use Validator;
use Auth;

class RegionController extends Controller
{
    public function regions_countries_list($id)
    {
        $regions = Regions::findOrFail(decrypt($id));
        return view('admin.regions_countries_list', compact('regions'));
    }

    public function manage_regions()
    {
        $regions = Regions::all();
        return view('admin.regions', compact('regions'));
    }

    public function add_regions()
    {
        $countries = Countries::all();
        return view('admin.add_regions', compact('countries'));
    }

    public function save_regions(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'code' => 'required',
            'country_id' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }
        $data['name'] = $request->name;
        $data['code'] = $request->code;
        $data['created_by'] = Auth::user()->id;
        if ($request->hasFile('region_icon')) {
            $validator = Validator::make($request->all(), [
                'region_icon' => 'required|image|mimes:jpg,png,jpeg,gif,svg,webp'
            ]);
            if ($validator->fails()) {
                return back()->with('error', 'Invalid Icon');
            }
            $image = $request->file('region_icon');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/regions/', $image_new);
            $data['region_icon'] = $image_new;
        }
        $regiondata = Regions::create($data);
        foreach ($request->country_id as $country_id) {
            $rec['region_id'] = $regiondata->id;
            $rec['country_id'] = $country_id;
            RegionCountries::create($rec);
        }
        return redirect()->route('admin.manage_regions')->with('success', 'Successfully Added.');
    }

    public function delete_regions($id)
    {
        $getData1 = Regions::findOrFail(decrypt($id));
        $getData2 = RegionCountries::where('region_id', $getData1->id)->delete();
        if (\File::exists(public_path('admin/assets/regions/' . $getData1->region_icon))) {
            \File::delete(public_path('admin/assets/regions/' . $getData1->region_icon));
        }
        $getData1->delete();
        return back()->with('success', 'Data Deleted Successfully !');
    }

    public function edit_regions($id)
    {
        $region = Regions::findOrFail(decrypt($id));
        $countries = Countries::all();
        return view("admin.edit_regions", compact('region', 'countries'));
    }

    public function update_regions(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required',
            'name' => 'required',
            'code' => 'required',
            'country_id' => 'required'
        ]);

        if ($validator->fails()) {
            return back()->withInput()->with('error', 'All fields required !');
        }
        $GetData = Regions::findOrFail($request->id);
        $GetData->name = $request->name;
        $GetData->code = $request->code;
        if ($request->hasFile('region_icon')) {
            $validator = Validator::make($request->all(), [
                'region_icon' => 'required|image|mimes:jpg,png,jpeg,gif,svg,webp'
            ]);

            if ($validator->fails()) {
                return back()->with('error', 'Invalid Icon');
            }

            if (\File::exists(public_path('admin/assets/regions/' . $GetData->region_icon))) {

                \File::delete(public_path('admin/assets/regions/' . $GetData->region_icon));
            }

            $image = $request->file('region_icon');
            $image_new = time() . $image->getClientOriginalName();
            $image->move('admin/assets/regions/', $image_new);
            $GetData->region_icon = $image_new;
        }
        $GetData->save();

        $rd = Regions::findOrFail($request->id);
        $rec = RegionCountries::where('region_id', $GetData->id)->delete();
        foreach ($request->country_id as $countryid) {
            $recData['region_id'] = $rd->id;
            $recData['country_id'] = $countryid;
            RegionCountries::create($recData);
        }
        return redirect()->route('admin.manage_regions')->with('success', 'Successfully Updated.');
    }


}
