<?php

namespace App\Http\Controllers;

use App\Mail\VerificationCode;
use App\Models\Countries;
use App\Models\MyPackages;
use App\Models\MyPackagesRegionCountries;
use App\Models\Record;
use App\Models\Regions;
use App\Models\Setting;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;
use Auth;
use Hash;


class WebsiteController extends Controller
{

    public function wrapError($messages)
    {
        $error = [
            'code' => '500',
            'type' => 'error',
            'messages' => $messages,
        ];

        return $error;
    }

    public function wrapSuccess($messages)
    {
        $error = [
            'code' => '200',
            'type' => 'success',
            'messages' => $messages,
        ];

        return $error;
    }

    public function loginerror()
    {
        return $this->wrapError('please login first');
    }

    public function home(Request $request)
    {
        if (!isset($request->username)) {
            return $this->wrapError('username required');
        }
        if (!isset($request->password)) {
            return $this->wrapError('password required');
        }
        $phone = $request->username;
        $password = base64_decode($request->password);

        if (Auth::check() && Auth::user()->type == "user") {
            return redirect()->route('dashboard');
        } else {
            $check = User::where('phone', $phone)->count();
            if ($check > 0) {
                if (auth()->attempt(['phone' => $phone, 'password' => $password, 'type' => 'user'])) {
                    if (Auth::check() && Auth::user()->type == "user") {
                        return redirect()->route('dashboard');
                    }
                } else {
                    return $this->wrapError('Invalid username password.');
                }
            }
            else
            {
                return $this->wrapError('User not exist need to register.');
            }
        }
    }

    public function userlogout()
    {
        if (Auth::check() && Auth::user()->type == "user")
        {
            Auth::logout();
            return $this->wrapSuccess('Logged out successfully.');
        }
        else
        {
            return $this->wrapError('not logged in.');
        }
    }

    public function dashboard()
    {
        return view("website.home");
    }

    public function country_packages($id, Request $request)
    {
        $did = decrypt($id);
        $query = MyPackages::where('type', '1')
            ->whereHas('myPackages', function ($query) use ($did) {
                $query->where('country_region_id', $did);
            });
        if (isset($request->title) && !empty($request->title)) {
            $query->where('title', 'like', '%' . $request->title . '%');
        }
        $packages = $query->get();
        $setting = Setting::first();
        $country = Countries::findOrFail($did);
        return view("website.country_packages", compact('packages', 'country', 'setting', 'request'));
    }

    public function region_packages($id, Request $request)
    {
        $did = decrypt($id);
        $query = MyPackages::where('type', '2')
            ->whereHas('myPackages', function ($query) use ($did) {
                $query->where('country_region_id', $did);
            });
        if (isset($request->title) && !empty($request->title)) {
            $query->where('title', 'like', '%' . $request->title . '%');
        }
        $packages = $query->get();
        $setting = Setting::first();
        $region = Regions::findOrFail($did);
        return view("website.region_packages", compact('packages', 'setting', 'region', 'request'));
    }

    public function region_countries_list($id)
    {
        $region = Regions::where('id', decrypt($id))->with(['country_data'])->first();
        return view("website.region_countries_list", compact('region'));
    }

    public function instructions()
    {
        return view("website.instructions");
    }

    public function regions(Request $request)
    {
        if (isset($request->region) && !empty($request->region)) {
            $query = Regions::where('name', 'like', '%' . $request->region . '%');
        } else {
            $query = Regions::query();
        }
        $query->has('check_availability', '>', 0);
        $regions = $query->with(['check_availability'])->get();
        return view("website.regions", compact('regions', 'request'));
    }

    public function countries(Request $request)
    {
        if (isset($request->country) && !empty($request->country)) {
            $query = Countries::where('name', 'like', '%' . $request->country . '%');
        } else {
            $query = Countries::query();
        }
        $query->has('check_availability', '>', 0);
        $countries = $query->with(['check_availability'])->orderBy('name', 'asc')->get();

        return view("website.countries", compact('countries', 'request'));
    }

}
