@extends('admin.layout.master')

@section('title')
    Countries
@endsection

<link rel="stylesheet" href="{{ URL::asset('admin/assets/vendors/datatables.net-bs5/dataTables.bootstrap5.css') }}">

@section('content')

    <div class="page-content">

        <nav class="page-breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item"><a href="{{ route('admin./') }}">Home</a></li>
                <li class="breadcrumb-item active" aria-current="page">Countries</li>
            </ol>
        </nav>

        <div class="row">
            <div class="col-md-12">
                <div class="card">
                    <div class="card-body">
                        <div class="row mb-5">
                            <div class="col-md-10"><h6 class="card-title">Countries</h6></div>
                            <div class="col-md-2">
                                <button class="btn btn-outline-dark w-100" type="button" data-bs-toggle="modal"
                                        data-bs-target="#AddPartners">Add Countries
                                </button>
                            </div>
                        </div>
                        <div class="table-responsive">
                            <table id="dataTableExample" class="table">
                                <thead>
                                <tr>
                                    <th>Id</th>
                                    <th>Name</th>
                                    <th>Short Name</th>
                                    <th>Code</th>
                                    <th>Flag</th>
                                    <th>Created At</th>
                                    <th>Edit</th>
                                    <th>Delete</th>
                                </tr>
                                </thead>
                                <tbody>
                                @forelse($countries as $t=>$country)
                                    <tr>
                                        <td>{{ $t+1 }}</td>
                                        <td>{{ ($country->name) ? $country->name : '--' }}</td>
                                        <td>{{ ($country->iso2) ? $country->iso2 : '--' }}</td>
                                        <td>{{ ($country->code) ? $country->code : '--' }}</td>
                                        <td>
                                            <img src="{{ url::asset('admin/assets/flags/'.$country->flag) }}" alt="">
                                        </td>
                                        <td>{{ Carbon\Carbon::parse($country->created_at)->format('d-m-Y') }}</td>
                                        <td>
                                            <a data-bs-toggle="modal"
                                               data-bs-target="#UpdateTeam{{ $country->id }}"
                                               class="btn btn-outline-info btn-icon">
                                                <i data-feather="edit"></i>
                                            </a>
                                        </td>
                                        <td>
                                            <a onclick="return(confirm('Are you sure to delete this record permanently ?'))"
                                               href="{{ route('admin.delete_flag',[encrypt($country->id)]) }}"
                                               class="btn btn-outline-danger btn-icon">
                                                <i data-feather="trash"></i>
                                            </a>
                                        </td>
                                    </tr>


                                    {{--  update modal--}}
                                    <div class="modal fade" id="UpdateTeam{{ $country->id }}" tabindex="-1"
                                         aria-labelledby="exampleModalLabel" aria-hidden="true">
                                        <div class="modal-dialog modal-lg">
                                            <div class="modal-content">
                                                <div class="modal-header bg-dark">
                                                    <h5 class="modal-title text-white" id="exampleModalLabel">Edit
                                                        Countries</h5>
                                                    <button type="button" class="btn-close" data-bs-dismiss="modal"
                                                            aria-label="btn-close"></button>
                                                </div>
                                                <div class="modal-body">
                                                    <div class="container">
                                                        <form action="{{ route('admin.updatecountries') }}"
                                                              method="post" class="MyForm"
                                                              enctype="multipart/form-data">
                                                            @csrf
                                                            <input type="hidden" name="id" value="{{ $country->id }}">
                                                            <div class="row">
                                                                <div class="col-md-6">
                                                                    <div class="form-group">
                                                                        <label> Name </label>
                                                                        <input type="text" name="name"
                                                                               autocomplete="off"
                                                                               class="form-control MyInput"
                                                                               required="" placeholder="Name . . . "
                                                                               value="{{ $country->name }}">
                                                                    </div>
                                                                </div>
                                                                <div class="col-md-6">
                                                                    <div class="form-group">
                                                                        <label> Short Name </label>
                                                                        <input type="text" name="iso2"
                                                                               autocomplete="off"
                                                                               class="form-control MyInput"
                                                                               required="" placeholder="Short Name . . . "
                                                                               value="{{ $country->iso2 }}">
                                                                    </div>
                                                                </div>
                                                                <div class="col-md-12">
                                                                    <div class="form-group">
                                                                        <label> Country Code </label>
                                                                        <input type="text" name="code"
                                                                               autocomplete="off"
                                                                               class="form-control MyInput"
                                                                               required=""
                                                                               placeholder="Country Code . . . "
                                                                               value="{{ $country->code }}">
                                                                    </div>
                                                                </div>
                                                                <div class="col-md-12">
                                                                    <div class="form-group">
                                                                        <label> Flag </label>
                                                                        <input type="file" name="flag"
                                                                               autocomplete="off"
                                                                               class="form-control MyInput pt-3"
                                                                               accept="image/*">
                                                                    </div>
                                                                </div>
                                                                <div class="col-md-12 text-center">
                                                                    <button class="btn btn-dark MyButton" type="submit">
                                                                        Save
                                                                    </button>
                                                                </div>
                                                            </div>
                                                        </form>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                @empty
                                @endforelse
                                </tbody>
                            </table>
                        </div>

                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal -->
    <div class="modal fade" id="AddPartners" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header bg-dark">
                    <h5 class="modal-title text-white" id="exampleModalLabel">Add Countries</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="btn-close"></button>
                </div>
                <div class="modal-body">
                    <div class="container">
                        <form action="{{ route('admin.savecountries') }}" method="post" class="MyForm"
                              enctype="multipart/form-data">
                            @csrf
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label> Name </label>
                                        <input type="text" name="name" autocomplete="off"
                                               class="form-control MyInput"
                                               required="" placeholder="Name . . . ">
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label> Short Name </label>
                                        <input type="text" name="iso2" autocomplete="off"
                                               class="form-control MyInput"
                                               required="" placeholder="Short Name . . . ">
                                    </div>
                                </div>
                                <div class="col-md-12">
                                    <div class="form-group">
                                        <label> Country Code </label>
                                        <input type="text" name="code" autocomplete="off"
                                               class="form-control MyInput"
                                               required="" placeholder="Country Code . . . ">
                                    </div>
                                </div>
                                <div class="col-md-12">
                                    <div class="form-group">
                                        <label> Flag </label>
                                        <input type="file" name="flag" autocomplete="off"
                                               class="form-control MyInput pt-3" required accept="image/*">
                                    </div>
                                </div>
                                <div class="col-md-12 text-center">
                                    <button class="btn btn-dark MyButton" type="submit"> Save</button>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>

@endsection
@section('script')

    <script src="{{ URL::asset('admin/assets/vendors/datatables.net/jquery.dataTables.js') }}"></script>
    <script src="{{ URL::asset('admin/assets/vendors/datatables.net-bs5/dataTables.bootstrap5.js') }}"></script>
    <script src="{{ URL::asset('admin/assets/js/data-table.js') }}"></script>

@endsection
