<?php

use Illuminate\Support\Facades\Route;


Route::get('/clear', function () {

    Artisan::call('cache:clear');
    Artisan::call('config:clear');
    Artisan::call('config:cache');
    Artisan::call('view:clear');
    Artisan::call('route:clear');

    return "Cleared!";

});

//website routes
Route::get('/', [App\Http\Controllers\WebsiteController::class, 'Home'])->name('/');
Route::get('loginerror', [App\Http\Controllers\WebsiteController::class, 'loginerror'])->name('loginerror');

Route::middleware(['user-access'])->group(function () {
    Route::get('dashboard', [App\Http\Controllers\WebsiteController::class, 'dashboard'])->name('dashboard');
    Route::get('Regions', [App\Http\Controllers\WebsiteController::class, 'regions'])->name('regions');
    Route::get('Countries', [App\Http\Controllers\WebsiteController::class, 'countries'])->name('countries');
    Route::get('Local+Packages/{id}', [App\Http\Controllers\WebsiteController::class, 'country_packages'])->name('country_packages');
    Route::get('Regional+Packages/{id}', [App\Http\Controllers\WebsiteController::class, 'region_packages'])->name('region_packages');
    Route::get('Regional+Packages+Countries/{id}', [App\Http\Controllers\WebsiteController::class, 'region_countries_list'])->name('region_countries_list');
    Route::get('Instructions', [App\Http\Controllers\WebsiteController::class, 'instructions'])->name('instructions');
    Route::get('userlogout', [App\Http\Controllers\WebsiteController::class, 'userlogout'])->name('userlogout');
});


Route::name('admin.')->prefix('admin')->group(function () {

    Route::get('/clear', function () {

        Artisan::call('cache:clear');
        Artisan::call('config:clear');
        Artisan::call('config:cache');
        Artisan::call('view:clear');
        Artisan::call('route:clear');

        return "Cleared!";

    });

//    without login
    Route::match(['get', 'post'], '/login', [App\Http\Controllers\LoginController::class, 'adminLogin'])->name('login');

    Route::middleware(['admin-auth', 'user-access:admin'])->group(function () {

//    After Login
        Route::get('/', [App\Http\Controllers\AdminHomeController::class, 'Dashboard'])->name('/');
        Route::get('/dashboard', [App\Http\Controllers\AdminHomeController::class, 'Dashboard'])->name('dashboard');
        Route::get('/home', [App\Http\Controllers\AdminHomeController::class, 'Dashboard'])->name('home');
        Route::post('/logout', [App\Http\Controllers\LoginController::class, 'logout'])->name('logout');

        // Admin Profile
        Route::get('/AdminProfile', [App\Http\Controllers\AdminHomeController::class, 'AdminProfile'])->name('AdminProfile');
        Route::post('/updateprofile', [App\Http\Controllers\AdminHomeController::class, 'updateprofile'])->name('updateprofile');

        // Application Setting
        Route::get('/setting', [App\Http\Controllers\SettingController::class, 'setting'])->name('setting');
        Route::post('/updatesetting', [App\Http\Controllers\SettingController::class, 'updatesetting'])->name('updatesetting');

        // Manage Amins
        Route::get('/Admins', [App\Http\Controllers\ManageWebsiteFunctionality::class, 'admins'])->name('admins');
        Route::post('/saveadmins', [App\Http\Controllers\ManageWebsiteFunctionality::class, 'saveadmins'])->name('saveadmins');
        Route::get('/deleteadmin/{id}', [App\Http\Controllers\ManageWebsiteFunctionality::class, 'deleteadmin'])->name('deleteadmin');
        Route::post('/updateadmin', [App\Http\Controllers\ManageWebsiteFunctionality::class, 'updateadmin'])->name('updateadmin');

        // Manage Countries
        Route::get('/Countries', [App\Http\Controllers\CountriesController::class, 'countries'])->name('manage_countries');
        Route::post('/savecountries', [App\Http\Controllers\CountriesController::class, 'savecountries'])->name('savecountries');
        Route::get('/delete_flag/{id}', [App\Http\Controllers\CountriesController::class, 'delete_flag'])->name('delete_flag');
        Route::post('/updatecountries', [App\Http\Controllers\CountriesController::class, 'updatecountries'])->name('updatecountries');

        // Manage Regions
        Route::get('/Regions+Countries+List/{id}', [App\Http\Controllers\RegionController::class, 'regions_countries_list'])->name('regions_countries_list');
        Route::get('/Regions', [App\Http\Controllers\RegionController::class, 'manage_regions'])->name('manage_regions');
        Route::get('/Add+Regions', [App\Http\Controllers\RegionController::class, 'add_regions'])->name('add_regions');
        Route::post('/save_regions', [App\Http\Controllers\RegionController::class, 'save_regions'])->name('save_regions');
        Route::get('/delete_regions/{id}', [App\Http\Controllers\RegionController::class, 'delete_regions'])->name('delete_regions');
        Route::get('/Edit+Regions/{id}', [App\Http\Controllers\RegionController::class, 'edit_regions'])->name('edit_regions');
        Route::post('/update_regions', [App\Http\Controllers\RegionController::class, 'update_regions'])->name('update_regions');

        // Sync Packages
        Route::get('/Sync+Packages', [App\Http\Controllers\PackagesController::class, 'sync_packages'])->name('sync_packages');
        Route::get('/Manage+eSim+Packages', [App\Http\Controllers\PackagesController::class, 'manage_esim_packages'])->name('manage_esim_packages');
        Route::get('/Make+Mine+Package/{id}', [App\Http\Controllers\PackagesController::class, 'make_mine'])->name('make_mine');
        Route::post('save_mine_packages', [App\Http\Controllers\PackagesController::class, 'save_mine_packages'])->name('save_mine_packages');
        Route::get('/Manage+My+Packages', [App\Http\Controllers\PackagesController::class, 'manage_my_packages'])->name('manage_my_packages');
        Route::get('/delete_custom_package/{id}', [App\Http\Controllers\PackagesController::class, 'delete_custom_package'])->name('delete_custom_package');
        Route::get('/edit_custom_package/{id}', [App\Http\Controllers\PackagesController::class, 'edit_custom_package'])->name('edit_custom_package');
        Route::post('/update_mine_packages', [App\Http\Controllers\PackagesController::class, 'update_mine_packages'])->name('update_mine_packages');

    });
});


?>
